@@ -1,18 +1,20 @@
 import curses, os, sys, types
-import setproctitle
 import kaa.tools
 import kaa.log
 from kaa import options, version, consts, config
 from . import app, keydef, frame
 
 from .. import document
-#from kaa.filetype.default import defaultmode
 from kaa import fileio
 
 CURSES_MOUSEINTERVAL = 200
 CURSES_ESCDELAY = '50'
 
 def _init(stdscr):
+    if not hasattr(stdscr, 'get_wch'):
+        raise RuntimeError(
+                'Kaa requires curses library with wide charater support.')
+        
     curses.start_color()
     curses.use_default_colors()
 
@@ -22,6 +24,7 @@ def _init(stdscr):
 #    curses.mousemask(curses.ALL_MOUSE_EVENTS)
 #    curses.mouseinterval(CURSES_MOUSEINTERVAL)
 
+
 def _restore():
     curses.noraw()
     curses.nl()
@@ -39,6 +42,7 @@ def run_userinit():
 
         sys.modules['__kaa__'] = module
 
+
 def main(stdscr):
     conf = config.Config()
     sys.path.insert(0, conf.KAADIR)
@@ -93,11 +97,28 @@ def main(stdscr):
     finally:
         _restore()
         _trace('end')
+
+
+def _init_term():
+    # http://fedoraproject.org/wiki/Features/256_Color_Terminals
+    term = os.environ.get('TERM')
+    if term in ('xterm', 'screen', 'Eterm'):
+        term = term+'-256color'
+        os.environ['TERM'] = term
+
+    if os.environ.get('TERM', '') == 'screen-256color':
+        termcap = os.environ.get('TERMCAP')
+        if termcap:
+            os.environ['TERMCAP'] = termcap.replace('Co#8', 'Co#256')
+    
 def run():
     if sys.version_info[:2] < (3, 3):
         raise RuntimeError('kaa requires Python 3.3 or later')
         
-    setproctitle.setproctitle('kaa')
+    if not getattr(__builtins__, 'kaa_freeze', False):
+        import setproctitle
+        setproctitle.setproctitle('kaa')
+        
     parser = options.build_parser()
 
     global opt
@@ -110,6 +131,7 @@ def run():
     if not os.environ.get('ESCDELAY'):
         os.environ['ESCDELAY'] = CURSES_ESCDELAY
 
+    _init_term()
     curses.wrapper(main)
 
 
