@@ -226,6 +226,12 @@ class Document:
         tol = self.buf.rfindchr('\n', 0, pos)
         return 0 if tol == -1 else tol+1
    
+    def find_newline(self, pos):
+        eol = self.buf.findchr('\n', pos, len(self.buf))
+        if eol == -1:
+            eol = len(self.buf)
+        return eol
+        
     def _findeol(self, pos):
         """Find next occurrence of newline"""
 
@@ -388,6 +394,7 @@ class Undo:
         if not block.can_undo():
             # Nothing happend
             del self._actions[-1]
+            self._next_undo = len(self._actions)
         else:
             block._closed = True
 
