@@ -63,9 +63,11 @@ class MsgBoxMode(dialogmode.DialogMode):
                 popup.destroy()
 
     def _runcallback(self, c):
-        self.callback(c)
+        if self.callback:
+            self.callback(c)
 
     def on_esc_pressed(self, wnd, event):
+        super().on_esc_pressed(wnd, event)
         self.on_shortcut(wnd, None)
 
     def _show_window(self):
